@@ -7,6 +7,7 @@ import re
 
 from markdoc.cache import DocumentCache, RenderCache, read_from
 from markdoc.config import Config
+from markdoc.render import make_relative
 
 
 Config.register_default('listing-filename', '_list.html')
@@ -21,7 +22,9 @@ class Builder(object):
         
         self.doc_cache = DocumentCache(base=self.config.wiki_dir)
         
-        render_func = lambda path, doc: self.config.markdown().convert(doc)
+        def render_func(path, doc):
+            level = len(path.lstrip('/').split('/')) - 1
+            return self.config.markdown(curr_path=path).convert(doc)
         self.render_cache = RenderCache(render_func, self.doc_cache)
         
         render_doc_func = lambda path, doc: self.render_document(path, cache=False)
@@ -155,6 +158,7 @@ class Builder(object):
             'sub_directories': sub_directories,
             'pages': pages,
             'files': files,
+            'make_relative': lambda href: make_relative(directory, href),
         }
     
     def render(self, path, cache=True):
@@ -171,6 +175,7 @@ class Builder(object):
         context['content'] = self.render(path)
         context['title'] = self.title(path)
         context['crumbs'] = self.crumbs(path)
+        context['make_relative'] = lambda href: make_relative(path, href)
         
         template = self.config.template_env.get_template('document.html')
         return template.render(context)
@@ -189,6 +194,7 @@ class Builder(object):
         crumbs.append((jinja2.Markup('<span class="list-crumb">list</span>'), None))
         
         context['crumbs'] = crumbs
+        context['make_relative'] = lambda href: make_relative(path + '/', href)
         
         template = self.config.template_env.get_template('listing.html')
         return template.render(context)
